==> stepfunctions-tasks-1.18.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/S3LocationBindOptions.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * Options for binding an S3 Location.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.8 (build bd5ef4d)", date = "2019-11-25T14:22:25.753Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.S3LocationBindOptions")
@software.amazon.jsii.Jsii.Proxy(S3LocationBindOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface S3LocationBindOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Allow reading from the S3 Location.
     * 
     * Default: false
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default java.lang.Boolean getForReading() {
        return null;
    }

    /**
     * Allow writing to the S3 Location.
     * 
     * Default: false
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default java.lang.Boolean getForWriting() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.Boolean forReading;
        private java.lang.Boolean forWriting;

        /**
         * Sets the value of ForReading
         * @param forReading Allow reading from the S3 Location.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder forReading(java.lang.Boolean forReading) {
            this.forReading = forReading;
            return this;
        }

        /**
         * Sets the value of ForWriting
         * @param forWriting Allow writing to the S3 Location.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder forWriting(java.lang.Boolean forWriting) {
            this.forWriting = forWriting;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3LocationBindOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public S3LocationBindOptions build() {
            return new Jsii$Proxy(forReading, forWriting);
        }
    }

    /**
     * An implementation for {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3LocationBindOptions {
        private final java.lang.Boolean forReading;
        private final java.lang.Boolean forWriting;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.forReading = this.jsiiGet("forReading", java.lang.Boolean.class);
            this.forWriting = this.jsiiGet("forWriting", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean forReading, final java.lang.Boolean forWriting) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.forReading = forReading;
            this.forWriting = forWriting;
        }

        @Override
        public java.lang.Boolean getForReading() {
            return this.forReading;
        }

        @Override
        public java.lang.Boolean getForWriting() {
            return this.forWriting;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getForReading() != null) {
                data.set("forReading", om.valueToTree(this.getForReading()));
            }
            if (this.getForWriting() != null) {
                data.set("forWriting", om.valueToTree(this.getForWriting()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions-tasks.S3LocationBindOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3LocationBindOptions.Jsii$Proxy that = (S3LocationBindOptions.Jsii$Proxy) o;

            if (this.forReading != null ? !this.forReading.equals(that.forReading) : that.forReading != null) return false;
            return this.forWriting != null ? this.forWriting.equals(that.forWriting) : that.forWriting == null;
        }

        @Override
        public int hashCode() {
            int result = this.forReading != null ? this.forReading.hashCode() : 0;
            result = 31 * result + (this.forWriting != null ? this.forWriting.hashCode() : 0);
            return result;
        }
    }
}

==> stepfunctions-tasks-1.33.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/S3LocationBindOptions.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * Options for binding an S3 Location.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.3.0 (build 8ae966b)", date = "2020-04-17T19:11:37.925Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.S3LocationBindOptions")
@software.amazon.jsii.Jsii.Proxy(S3LocationBindOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface S3LocationBindOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Allow reading from the S3 Location.
     * <p>
     * Default: false
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getForReading() {
        return null;
    }

    /**
     * Allow writing to the S3 Location.
     * <p>
     * Default: false
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getForWriting() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.Boolean forReading;
        private java.lang.Boolean forWriting;

        /**
         * Sets the value of {@link S3LocationBindOptions#getForReading}
         * @param forReading Allow reading from the S3 Location.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder forReading(java.lang.Boolean forReading) {
            this.forReading = forReading;
            return this;
        }

        /**
         * Sets the value of {@link S3LocationBindOptions#getForWriting}
         * @param forWriting Allow writing to the S3 Location.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder forWriting(java.lang.Boolean forWriting) {
            this.forWriting = forWriting;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link S3LocationBindOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public S3LocationBindOptions build() {
            return new Jsii$Proxy(forReading, forWriting);
        }
    }

    /**
     * An implementation for {@link S3LocationBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements S3LocationBindOptions {
        private final java.lang.Boolean forReading;
        private final java.lang.Boolean forWriting;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.forReading = this.jsiiGet("forReading", java.lang.Boolean.class);
            this.forWriting = this.jsiiGet("forWriting", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean forReading, final java.lang.Boolean forWriting) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.forReading = forReading;
            this.forWriting = forWriting;
        }

        @Override
        public java.lang.Boolean getForReading() {
            return this.forReading;
        }

        @Override
        public java.lang.Boolean getForWriting() {
            return this.forWriting;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getForReading() != null) {
                data.set("forReading", om.valueToTree(this.getForReading()));
            }
            if (this.getForWriting() != null) {
                data.set("forWriting", om.valueToTree(this.getForWriting()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions-tasks.S3LocationBindOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            S3LocationBindOptions.Jsii$Proxy that = (S3LocationBindOptions.Jsii$Proxy) o;

            if (this.forReading != null ? !this.forReading.equals(that.forReading) : that.forReading != null) return false;
            return this.forWriting != null ? this.forWriting.equals(that.forWriting) : that.forWriting == null;
        }

        @Override
        public int hashCode() {
            int result = this.forReading != null ? this.forReading.hashCode() : 0;
            result = 31 * result + (this.forWriting != null ? this.forWriting.hashCode() : 0);
            return result;
        }
    }
}
